pyRVT
+++++

.. image:: https://travis-ci.org/arkottke/pyrvt.svg?branch=master   
    :target: https://travis-ci.org/arkottke/pyrvt

.. image:: https://readthedocs.org/projects/pyrvt/badge/?version=latest
    :target: http://pyrvt.readthedocs.org/

.. image:: https://coveralls.io/repos/arkottke/pyrvt/badge.png?branch=master 
    :target: https://coveralls.io/r/arkottke/pyrvt?branch=master

.. image:: https://landscape.io/github/arkottke/pyrvt/master/landscape.svg?style=flat
    :target: https://landscape.io/github/arkottke/pyrvt

.. image:: https://badges.gitter.im/Join%20Chat.svg
    :alt: Join the chat at https://gitter.im/arkottke/pyrvt
    :target: https://gitter.im/arkottke/pyrvt?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge

A Python library and command-line application for using random vibration theory
to transform between acceleration Fourier amplitude spectrum and acceleration
response spectrum.

Information on the installation and usage can be found in the documentation_.

.. _documentation: http://pyrvt.readthedocs.org/
